@@ -121,8 +121,8 @@
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @export
-#Test: Partial Bootstrapped Network Statistics----
-# Updated 25.09.2020
+#Test: Bootstrapped Network Statistics----
+# Updated 01.12.2020
 test.bootSemNeT <- function (..., measures = c("ASPL", "CC", "Q"), formula = NULL, groups = NULL)
 {
     #Missing arguments
@@ -165,7 +165,7 @@ test.bootSemNeT <- function (..., measures = c("ASPL", "CC", "Q"), formula = NUL
     temp.res <- list()
     
     for(i in 1:length(input))
-    {temp.res[[props[i]]] <- boot.one.test(input[[i]], measures = measures, formula = formula, groups = groups)}
+    {temp.res[[props[i]]] <- suppressPackageStartupMessages(boot.one.test(input[[i]], measures = measures, formula = formula, groups = groups))}
     
     # Insert full results
     res$fullResults <- temp.res
@@ -222,6 +222,8 @@ test.bootSemNeT <- function (..., measures = c("ASPL", "CC", "Q"), formula = NUL
             tab.acov <- cbind(round(adj.vals, 3), tab.acov)
             #Add residual degrees of freedom
             tab.acov <- as.data.frame(cbind(tab.acov[,c(1:(length(names)+2))], unlist(res.df), tab.acov[,(length(names)+3):ncol(tab.acov)]), stringsAsFactors = FALSE)
+            #Recheck names
+            name <- colnames(tab.acov)[1:length(name)]
             
             # Provided direction if two groups
             if(length(name) == 2)
@@ -264,6 +266,8 @@ test.bootSemNeT <- function (..., measures = c("ASPL", "CC", "Q"), formula = NUL
                 tab.acov <- cbind(round(adj.vals[grep(measures[[j]], row.names(adj.vals)),], 3), tab.acov)
                 #Add residual degrees of freedom
                 tab.acov <- as.data.frame(cbind(tab.acov[,c(1:(length(names)+2))], unlist(res.val), tab.acov[,(length(names)+3):ncol(tab.acov)]), stringsAsFactors = FALSE)
+                #Recheck names
+                name <- colnames(tab.acov)[1:length(name)]
                 
                 # Provided direction if two groups
                 if(length(name) == 2)
